==> apigateway-1.188.0-sources.jar: software/amazon/awscdk/services/apigateway/CfnUsagePlanKeyProps.java <==
package software.amazon.awscdk.services.apigateway;

/**
 * Properties for defining a `CfnUsagePlanKey`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.apigateway.*;
 * CfnUsagePlanKeyProps cfnUsagePlanKeyProps = CfnUsagePlanKeyProps.builder()
 *         .keyId("keyId")
 *         .keyType("keyType")
 *         .usagePlanId("usagePlanId")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.72.0 (build 4b8828b)", date = "2023-01-11T14:44:48.340Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.apigateway.$Module.class, fqn = "@aws-cdk/aws-apigateway.CfnUsagePlanKeyProps")
@software.amazon.jsii.Jsii.Proxy(CfnUsagePlanKeyProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnUsagePlanKeyProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The ID of the usage plan key.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getKeyId();

    /**
     * The type of usage plan key.
     * <p>
     * Currently, the only valid key type is <code>API_KEY</code> .
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getKeyType();

    /**
     * The ID of the usage plan.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getUsagePlanId();

    /**
     * @return a {@link Builder} of {@link CfnUsagePlanKeyProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnUsagePlanKeyProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnUsagePlanKeyProps> {
        java.lang.String keyId;
        java.lang.String keyType;
        java.lang.String usagePlanId;

        /**
         * Sets the value of {@link CfnUsagePlanKeyProps#getKeyId}
         * @param keyId The ID of the usage plan key. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder keyId(java.lang.String keyId) {
            this.keyId = keyId;
            return this;
        }

        /**
         * Sets the value of {@link CfnUsagePlanKeyProps#getKeyType}
         * @param keyType The type of usage plan key. This parameter is required.
         *                Currently, the only valid key type is <code>API_KEY</code> .
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder keyType(java.lang.String keyType) {
            this.keyType = keyType;
            return this;
        }

        /**
         * Sets the value of {@link CfnUsagePlanKeyProps#getUsagePlanId}
         * @param usagePlanId The ID of the usage plan. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder usagePlanId(java.lang.String usagePlanId) {
            this.usagePlanId = usagePlanId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnUsagePlanKeyProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnUsagePlanKeyProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnUsagePlanKeyProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnUsagePlanKeyProps {
        private final java.lang.String keyId;
        private final java.lang.String keyType;
        private final java.lang.String usagePlanId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.keyId = software.amazon.jsii.Kernel.get(this, "keyId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.keyType = software.amazon.jsii.Kernel.get(this, "keyType", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.usagePlanId = software.amazon.jsii.Kernel.get(this, "usagePlanId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.keyId = java.util.Objects.requireNonNull(builder.keyId, "keyId is required");
            this.keyType = java.util.Objects.requireNonNull(builder.keyType, "keyType is required");
            this.usagePlanId = java.util.Objects.requireNonNull(builder.usagePlanId, "usagePlanId is required");
        }

        @Override
        public final java.lang.String getKeyId() {
            return this.keyId;
        }

        @Override
        public final java.lang.String getKeyType() {
            return this.keyType;
        }

        @Override
        public final java.lang.String getUsagePlanId() {
            return this.usagePlanId;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("keyId", om.valueToTree(this.getKeyId()));
            data.set("keyType", om.valueToTree(this.getKeyType()));
            data.set("usagePlanId", om.valueToTree(this.getUsagePlanId()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-apigateway.CfnUsagePlanKeyProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnUsagePlanKeyProps.Jsii$Proxy that = (CfnUsagePlanKeyProps.Jsii$Proxy) o;

            if (!keyId.equals(that.keyId)) return false;
            if (!keyType.equals(that.keyType)) return false;
            return this.usagePlanId.equals(that.usagePlanId);
        }

        @Override
        public final int hashCode() {
            int result = this.keyId.hashCode();
            result = 31 * result + (this.keyType.hashCode());
            result = 31 * result + (this.usagePlanId.hashCode());
            return result;
        }
    }
}

==> apigateway-1.190.0-sources.jar: software/amazon/awscdk/services/apigateway/CfnUsagePlanKeyProps.java <==
package software.amazon.awscdk.services.apigateway;

/**
 * Properties for defining a `CfnUsagePlanKey`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.apigateway.*;
 * CfnUsagePlanKeyProps cfnUsagePlanKeyProps = CfnUsagePlanKeyProps.builder()
 *         .keyId("keyId")
 *         .keyType("keyType")
 *         .usagePlanId("usagePlanId")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.73.0 (build 6faeda3)", date = "2023-01-25T18:29:08.422Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.apigateway.$Module.class, fqn = "@aws-cdk/aws-apigateway.CfnUsagePlanKeyProps")
@software.amazon.jsii.Jsii.Proxy(CfnUsagePlanKeyProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnUsagePlanKeyProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The Id of the UsagePlanKey resource to be deleted.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getKeyId();

    /**
     * The type of a UsagePlanKey resource for a plan customer.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getKeyType();

    /**
     * The Id of the UsagePlan resource representing the usage plan containing the to-be-deleted UsagePlanKey resource representing a plan customer.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getUsagePlanId();

    /**
     * @return a {@link Builder} of {@link CfnUsagePlanKeyProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnUsagePlanKeyProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnUsagePlanKeyProps> {
        java.lang.String keyId;
        java.lang.String keyType;
        java.lang.String usagePlanId;

        /**
         * Sets the value of {@link CfnUsagePlanKeyProps#getKeyId}
         * @param keyId The Id of the UsagePlanKey resource to be deleted. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder keyId(java.lang.String keyId) {
            this.keyId = keyId;
            return this;
        }

        /**
         * Sets the value of {@link CfnUsagePlanKeyProps#getKeyType}
         * @param keyType The type of a UsagePlanKey resource for a plan customer. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder keyType(java.lang.String keyType) {
            this.keyType = keyType;
            return this;
        }

        /**
         * Sets the value of {@link CfnUsagePlanKeyProps#getUsagePlanId}
         * @param usagePlanId The Id of the UsagePlan resource representing the usage plan containing the to-be-deleted UsagePlanKey resource representing a plan customer. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder usagePlanId(java.lang.String usagePlanId) {
            this.usagePlanId = usagePlanId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnUsagePlanKeyProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnUsagePlanKeyProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnUsagePlanKeyProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnUsagePlanKeyProps {
        private final java.lang.String keyId;
        private final java.lang.String keyType;
        private final java.lang.String usagePlanId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.keyId = software.amazon.jsii.Kernel.get(this, "keyId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.keyType = software.amazon.jsii.Kernel.get(this, "keyType", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.usagePlanId = software.amazon.jsii.Kernel.get(this, "usagePlanId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.keyId = java.util.Objects.requireNonNull(builder.keyId, "keyId is required");
            this.keyType = java.util.Objects.requireNonNull(builder.keyType, "keyType is required");
            this.usagePlanId = java.util.Objects.requireNonNull(builder.usagePlanId, "usagePlanId is required");
        }

        @Override
        public final java.lang.String getKeyId() {
            return this.keyId;
        }

        @Override
        public final java.lang.String getKeyType() {
            return this.keyType;
        }

        @Override
        public final java.lang.String getUsagePlanId() {
            return this.usagePlanId;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("keyId", om.valueToTree(this.getKeyId()));
            data.set("keyType", om.valueToTree(this.getKeyType()));
            data.set("usagePlanId", om.valueToTree(this.getUsagePlanId()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-apigateway.CfnUsagePlanKeyProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnUsagePlanKeyProps.Jsii$Proxy that = (CfnUsagePlanKeyProps.Jsii$Proxy) o;

            if (!keyId.equals(that.keyId)) return false;
            if (!keyType.equals(that.keyType)) return false;
            return this.usagePlanId.equals(that.usagePlanId);
        }

        @Override
        public final int hashCode() {
            int result = this.keyId.hashCode();
            result = 31 * result + (this.keyType.hashCode());
            result = 31 * result + (this.usagePlanId.hashCode());
            return result;
        }
    }
}
